@@ -8,26 +8,50 @@
 #include "kapmanmainwindow.h"
 #include "gamescene.h"
 #include "settings.h"
-
-#include <QPointer>
-#include <KActionCollection>
-#include <KStandardGameAction>
-#include <KToggleAction>
-#include <KMessageBox>
-#include <KConfigDialog>
-#include <QInputDialog>
-#include <KLocalizedString>
-#include <QStatusBar>
-#include <KgDifficulty>
+// KDEGames
+#include <kdegames_version.h>
+#include <KgThemeProvider>
+#include <KgThemeSelector>
 #include <KScoreDialog>
+#include <KStandardGameAction>
+#include <KgDifficulty>
+// KF
+#include <KStandardGuiItem>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KToggleAction>
+#include <KToggleFullScreenAction>
+// Qt
 #include <QAction>
+#include <QInputDialog>
 #include <QLabel>
-
-#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
-#include <libkdegamesprivate/kgamethemeselector.h>
+#include <QPointer>
+#include <QStatusBar>
+#include <QMenuBar>
 
 KapmanMainWindow::KapmanMainWindow()
 {
+    m_themeProvider = new KgThemeProvider(QByteArray(), this); // empty config key to disable internal config
+    m_themeProvider->discoverThemes(
+#if KDEGAMES_VERSION < QT_VERSION_CHECK(7, 4, 0)
+        "appdata",
+#endif
+        QStringLiteral("themes"),   // theme data location
+        QStringLiteral("default")); // default theme name
+
+    const QByteArray themeIdentifier = Settings::theme().toUtf8();
+    const QList<const KgTheme *> themes = m_themeProvider->themes();
+    for (auto* theme : themes) {
+        if (theme->identifier() == themeIdentifier) {
+            m_themeProvider->setCurrentTheme(theme);
+            break;
+        }
+    }
+    connect(m_themeProvider, &KgThemeProvider::currentThemeChanged, this, &KapmanMainWindow::onThemeChanged);
+
+    m_themeSelector = new KgThemeSelector(m_themeProvider);
+
     // Initialize the game
     m_game = nullptr;
     m_view = nullptr;
@@ -35,12 +59,15 @@ KapmanMainWindow::KapmanMainWindow()
     KStandardGameAction::gameNew(this, &KapmanMainWindow::newGame, actionCollection());
     KStandardGameAction::highscores(this, &KapmanMainWindow::showHighscores, actionCollection());
     KStandardAction::preferences(this, &KapmanMainWindow::showSettings, actionCollection());
+
+    KStandardAction::fullScreen(this, &KapmanMainWindow::viewFullScreen, this, actionCollection());
+
     KStandardGameAction::quit(this, &KapmanMainWindow::close, actionCollection());
-    KToggleAction *soundAction = new KToggleAction(i18n("&Play Sounds"), this);
+    auto soundAction = new KToggleAction(i18n("&Play Sounds"), this);
     soundAction->setChecked(Settings::sounds());
     actionCollection()->addAction(QStringLiteral("sounds"), soundAction);
     connect(soundAction, &KToggleAction::triggered, this, &KapmanMainWindow::setSoundsEnabled);
-    QAction *levelAction = new QAction(i18n("&Change Level"), this);
+    auto levelAction = new QAction(i18n("&Change Level"), this);
     actionCollection()->addAction(QStringLiteral("level"), levelAction);
     connect(levelAction, &QAction::triggered, this, &KapmanMainWindow::changeLevel);
     // Add a statusbar to show level,score,lives information
@@ -53,20 +80,24 @@ KapmanMainWindow::KapmanMainWindow()
     m_statusBar->addPermanentWidget(mLives);
 
     // Initialize the KgDifficulty singleton
-    Kg::difficulty()->addStandardLevelRange(
-        KgDifficultyLevel::Easy, KgDifficultyLevel::Hard, //range
-        KgDifficultyLevel::Medium //default
+    Kg::difficulty()->addStandardLevelRange(KgDifficultyLevel::Easy,
+                                            KgDifficultyLevel::Hard, // range
+                                            KgDifficultyLevel::Medium // default
     );
     KgDifficultyGUI::init(this);
     connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged, this, &KapmanMainWindow::initGame);
     // Setup the window
     setupGUI();
 
+    menuBar()->setVisible(!isFullScreen());
+    statusBar()->setVisible(!isFullScreen());
+
     initGame();
 }
 
 KapmanMainWindow::~KapmanMainWindow()
 {
+    delete m_themeSelector;
     delete m_statusBar;
     delete m_game;
     delete m_view;
@@ -84,7 +115,7 @@ void KapmanMainWindow::initGame()
 
     // Create a new GameView instance
     delete m_view;
-    m_view = new GameView(m_game);
+    m_view = new GameView(m_game, m_themeProvider->currentTheme());
     m_view->setBackgroundBrush(Qt::black);
     setCentralWidget(m_view);
     m_view->setFocus();
@@ -96,7 +127,7 @@ void KapmanMainWindow::initGame()
 
 void KapmanMainWindow::newGame()
 {
-    bool gameRunning;       // True if the game is running (game timer is active), false otherwise
+    bool gameRunning; // True if the game is running (game timer is active), false otherwise
 
     gameRunning = m_game->getTimer()->isActive();
     // If the game is running
@@ -106,7 +137,10 @@ void KapmanMainWindow::newGame()
     }
 
     // Confirm before starting a new game
-    if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to quit the current game?"), i18nc("@title:window", "New Game")) == KMessageBox::Yes) {
+    if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to quit the current game?"),
+                                  i18nc("@title:window", "New Game"),
+                                  KGuiItem(i18nc("@action;button", "Quit Game"), QStringLiteral("window-close")),
+                                  KStandardGuiItem::cancel()) == KMessageBox::Yes) {
         // Start a new game
         initGame();
     } else {
@@ -120,7 +154,7 @@ void KapmanMainWindow::newGame()
 
 void KapmanMainWindow::handleGameOver()
 {
-    bool gameRunning;       // True if the game is running (game timer is active), false otherwise
+    bool gameRunning; // True if the game is running (game timer is active), false otherwise
 
     gameRunning = m_game->getTimer()->isActive();
     // If the game is running
@@ -173,24 +207,21 @@ void KapmanMainWindow::setSoundsEnabled(bool p_enabled)
 
 void KapmanMainWindow::showSettings()
 {
-    if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
-        return;
-    }
-    KConfigDialog *settingsDialog = new KConfigDialog(this, QStringLiteral("settings"), Settings::self());
-    settingsDialog->addPage(new KGameThemeSelector(settingsDialog, Settings::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Theme"), QStringLiteral("kapman"));
-    settingsDialog->setFaceType(KConfigDialog::Plain); //only one page -> no page selection necessary
-    connect(settingsDialog, &KConfigDialog::settingsChanged, this, &KapmanMainWindow::loadSettings);
-    settingsDialog->show();
+    m_themeSelector->showAsDialog();
 }
 
-void KapmanMainWindow::loadSettings()
+void KapmanMainWindow::onThemeChanged(const KgTheme *theme)
 {
-    ((GameScene *)m_view->scene())->loadTheme();
+    // sync to settings store
+    Settings::setTheme(QString::fromUtf8(theme->identifier()));
+    Settings::self()->save();
+    // trigger update of resources, then display
+    ((GameScene *)m_view->scene())->loadTheme(theme);
 }
 
 void KapmanMainWindow::close()
 {
-    bool gameRunning;       // True if the game is running (game timer is active), false otherwise
+    bool gameRunning; // True if the game is running (game timer is active), false otherwise
 
     gameRunning = m_game->getTimer()->isActive();
     // If the game is running
@@ -199,7 +230,9 @@ void KapmanMainWindow::close()
         m_game->pause();
     }
     // Confirm before closing
-    if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to quit Kapman?"), i18nc("To quit Kapman", "Quit")) == KMessageBox::Yes) {
+    if (KMessageBox::warningYesNo(this, i18n("Are you sure you want to quit Kapman?"),
+                                  i18nc("To quit Kapman", "Quit"),
+                                  KStandardGuiItem::quit(), KStandardGuiItem::cancel()) == KMessageBox::Yes) {
         KXmlGuiWindow::close();
     } else {
         // If the game was running
@@ -212,23 +245,17 @@ void KapmanMainWindow::close()
 
 void KapmanMainWindow::displayLevel(unsigned int p_level)
 {
-    mLevel->setText(i18nc(
-                        "Used to display the current level of play to the user",
-                        "Level: %1", p_level));
+    mLevel->setText(i18nc("Used to display the current level of play to the user", "Level: %1", p_level));
 }
 
 void KapmanMainWindow::displayScore(unsigned int p_score)
 {
-    mScore->setText(i18nc(
-                        "Used to inform the user of their current score", "Score: %1",
-                        p_score));
+    mScore->setText(i18nc("Used to inform the user of their current score", "Score: %1", p_score));
 }
 
 void KapmanMainWindow::displayLives(unsigned int p_lives)
 {
-    mLives->setText(i18nc(
-                        "Used to tell the user how many lives they have left", "Lives: %1",
-                        p_lives));
+    mLives->setText(i18nc("Used to tell the user how many lives they have left", "Lives: %1", p_lives));
 }
 
 void KapmanMainWindow::resetStatusBar()
@@ -237,3 +264,11 @@ void KapmanMainWindow::resetStatusBar()
     displayScore(0);
     displayLives(initLives);
 }
+
+void KapmanMainWindow::viewFullScreen(bool fullScreen)
+{
+    KToggleFullScreenAction::setFullScreen(this, fullScreen);
+
+    menuBar()->setVisible(!fullScreen);
+    statusBar()->setVisible(!fullScreen);
+}
